{% if tags %}
    <div class="highlight-tags">
        <div class="tags">
            {% for t in tags %}
                <a class="tag-link"
                   href="{{ url_for('projects.tag_search', tag=t) }}">{{ t }}</a>
            {% endfor %}
        </div>
    </div>
{% endif %}
